==> firebase_admin-0.1.4.tar.gz: lib/src/auth/token_verifier.dart <==
import 'package:openid_client/openid_client.dart';

import '../../firebase_admin.dart';
import '../app/app_extension.dart';
import 'package:meta/meta.dart';
import '../utils/validator.dart' as validator;

/// Class for verifying general purpose Firebase JWTs.
///
/// This verifies ID tokens and session cookies.
class FirebaseTokenVerifier {
  final App app;
  final String projectId;

  final String _verifyApiName = 'verifyIdToken()';
  final String _jwtName = 'ID token';

  static FirebaseTokenVerifier Function(App app) factory =
      (app) => FirebaseTokenVerifier(app);

  FirebaseTokenVerifier(this.app) : projectId = app.projectId {
    if (projectId == null) {
      throw FirebaseAuthError.invalidCredential(
        'Must initialize app with a cert credential or set your Firebase project ID as the '
        'GOOGLE_CLOUD_PROJECT environment variable to call $_verifyApiName.',
      );
    }
  }

  /// Verifies the format and signature of a Firebase Auth JWT token.
  Future<IdToken> verifyJwt(String jwtToken) async {
    if (jwtToken == null) {
      throw FirebaseAuthError.invalidArgument(
        'First argument to $_verifyApiName must be a Firebase $_jwtName string.',
      );
    }

    var client = await getOpenIdClient();

    var credential = client.createCredential(idToken: jwtToken);

    await for (var e in credential.validateToken()) {
      throw FirebaseAuthError.invalidArgument(
          'Validating $_jwtName failed: $e');
    }

    if (!validator.isUid(credential.idToken.claims.subject)) {
      throw FirebaseAuthError.invalidArgument(
          '$_jwtName has "sub" (subject) claim which is not a valid uid');
    }

    return credential.idToken;
  }

  @visibleForTesting
  Future<Client> getOpenIdClient() async {
    var issuer = await Issuer.discover(Issuer.firebase(projectId));
    return Client(issuer, projectId);
  }
}

==> firebase_admin-0.2.0-dev.3.tar.gz: lib/src/auth/token_verifier.dart <==
import 'package:openid_client/openid_client.dart';

import '../../firebase_admin.dart';
import '../app/app_extension.dart';
import 'package:meta/meta.dart';
import '../utils/validator.dart' as validator;

/// Class for verifying general purpose Firebase JWTs.
///
/// This verifies ID tokens and session cookies.
class FirebaseTokenVerifier {
  final App app;
  final String? projectId;

  final String _verifyApiName = 'verifyIdToken()';
  final String _jwtName = 'ID token';

  static FirebaseTokenVerifier Function(App app) factory =
      (app) => FirebaseTokenVerifier(app);

  FirebaseTokenVerifier(this.app) : projectId = app.projectId {
    if (projectId == null) {
      throw FirebaseAuthError.invalidCredential(
        'Must initialize app with a cert credential or set your Firebase project ID as the '
        'GOOGLE_CLOUD_PROJECT environment variable to call $_verifyApiName.',
      );
    }
  }

  /// Verifies the format and signature of a Firebase Auth JWT token.
  Future<IdToken> verifyJwt(String jwtToken) async {
    var client = await getOpenIdClient();

    var credential = client.createCredential(idToken: jwtToken);

    await for (var e in credential.validateToken()) {
      throw FirebaseAuthError.invalidArgument(
          'Validating $_jwtName failed: $e');
    }

    if (!validator.isUid(credential.idToken.claims.subject)) {
      throw FirebaseAuthError.invalidArgument(
          '$_jwtName has "sub" (subject) claim which is not a valid uid');
    }

    return credential.idToken;
  }

  @visibleForTesting
  Future<Client> getOpenIdClient() async {
    var issuer = await Issuer.discover(Issuer.firebase(projectId!));
    return Client(issuer, projectId);
  }
}
